require 'spec_helper'

describe Quby::Compiler::Outputs::SeedSerializer do
  it 'generates yaml' do
    questionnaire = dsl("test") { title "Test" }
    serializer = described_class.new(questionnaire)
    expect(serializer.generate).to match([a_hash_including('name' => "Test")])
  end

  it 'uses seeds_patch' do
    questionnaire = dsl("test") do
      title "Test"
      roqua_keys "testo1", "testo2"
      seeds_patch "testo1" => {"name" => "Override"}
    end

    serializer = described_class.new(questionnaire)
    expect(serializer.generate).to match([
      a_hash_including('key' => 'testo1', 'name' => "Override"),
      a_hash_including('key' => 'testo2', 'name' => "Test")
    ])
  end


  it 'strips slashes after question numbers' do
    questionnaire = dsl("test") do
      title "Test Quest"
      panel do
        question :v_1, type: :string, title: '  12\. vraag nummer 1'
      end
    end
    serializer = described_class.new(questionnaire)
    expect(serializer.generate.first['quests']).to eq("v_1"=>"  12. vraag nummer 1")
  end

  def dsl(key, &block)
    Quby::Compiler::DSL.build(key, nil, &block)
  end
end
